#[non_exhaustive]pub enum AbortKind {
SingleOpenInterval,
RecordedAtRegression,
DeleteOutsideArchive,
CrossLineage,
BranchImmutable,
BranchesFrozen,
NotAGuard,
}Expand description
A guard abort recognised by its message (4.3).
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
SingleOpenInterval
RecordedAtRegression
DeleteOutsideArchive
CrossLineage
A concept id already held by a different lineage (v12, 15.2, D-214).
BranchImmutable
An UPDATE that would move a concept between lineages (v12, D-214).
BranchesFrozen
Any write to branches other than an insert (v12, 15.2).
NotAGuard
Not one of our guards — an ordinary engine error.