Module as_of

Module as_of 

Structs

NodeAttributes
Node attribute payload hydrated from concepts table or transaction_log.

Functions

hydrate_attributes
Hydrate attributes for a list of node IDs based on the specified AttributeMode (5.2).
query_as_of_edges
Query valid-time graph edges under current belief as of ts (5.2).