Module replay

Module replay 

Structs

ChainCheck
The result of a verify_snapshot_chain cross-check.
MaterializedState
Full materialized state reconstructed from transaction_log replay (5.5).

Functions

reconstruct
Reconstruct database state as believed at past instant ts using window-function log fold (5.5, D-026).
verify_snapshot_chain
Fold from genesis and compare against the composed answer (5.5, T5.3, D-092).